@@ -4,21 +4,25 @@
 import sys
 import gtk
 import hildon
-from os import path, system
+from os import listdir, path, system
 from ConfigParser import SafeConfigParser
 
-version = "1.2-2"
+version = "1.3-0"
 autostart = False
 confirmDisconnect = True
+showConnected = True
 stopTracking = False
 skipSystemCheck = False
+connectedIcon = "Symbol"
 
 class Main(object):
     def __init__(self):
         global autostart
         global confirmDisconnect
         global stopTracking
+        global showConnected
         global skipSystemCheck
+        global connectedIcon
         autostartDisabled = False
        
         self.parser = SafeConfigParser()
@@ -35,8 +39,10 @@ class Main(object):
             configFile = open('/home/user/.openssh-status-widget', 'w')
             self.parser.add_section('options')
             self.parser.set('options', 'confirmDisconnect', str(confirmDisconnect))
+            self.parser.set('options', 'showConnected', str(showConnected))
             self.parser.set('options', 'stopTracking', str(stopTracking))
             self.parser.set('options', 'skipSystemCheck', str(skipSystemCheck))
+            self.parser.set('options', 'connectedIcon', str(connectedIcon))
             self.parser.write(configFile)
             configFile.close()
         else:
@@ -46,6 +52,10 @@ class Main(object):
                     confirmDisconnect = self.parser.getboolean('options', 'confirmDisconnect')
                 else:
                     self.parser.set('options', 'confirmDisconnect', str(confirmDisconnect))
+                if self.parser.has_option('options', 'showConnected'):
+                    showConnected = self.parser.getboolean('options', 'showConnected')
+                else:
+                    self.parser.set('options', 'showConnected', str(showConnected))
                 if self.parser.has_option('options', 'stopTracking'):
                     stopTracking = self.parser.getboolean('options', 'stopTracking')
                 else:
@@ -54,6 +64,10 @@ class Main(object):
                     skipSystemCheck = self.parser.getboolean('options', 'skipSystemCheck')
                 else:
                     self.parser.set('options', 'skipSystemCheck', str(skipSystemCheck))
+                if self.parser.has_option('options', 'connectedIcon'):
+                    connectedIcon = self.parser.get('options', 'connectedIcon')
+                else:
+                    self.parser.set('options', 'connectedIcon', str(connectedIcon))
         
         if not path.isfile("/etc/event.d/sshd"):
             system("sudo /usr/sbin/openssh-status.sh create_sshd")
@@ -68,6 +82,14 @@ class Main(object):
         if not autostart and not autostartDisabled:
             system("sudo /usr/sbin/openssh-status.sh insert_start")
             
+        self.list = []
+        for f in listdir('/usr/share/icons/hicolor/18x18/hildon/'):
+            if f[0:21] == "openssh-status_users_" and f <> "openssh-status_users_symbol.png" and f[-4:] ==".png":
+                f = f[21:-4]
+                self.list.append(f.title())
+        self.list.sort()
+        self.list.insert(0, "Symbol")
+        
         self.main()
     
     def main(self):
@@ -84,18 +106,40 @@ class Main(object):
         self.buttonConfirm = hildon.CheckButton(gtk.HILDON_SIZE_FULLSCREEN_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT)
         self.buttonConfirm.set_label("Confirm when disconnecting")
         
+        self.buttonShowConnected = hildon.CheckButton(gtk.HILDON_SIZE_FULLSCREEN_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT)
+        self.buttonShowConnected.set_label("Show status 'connected' in status area")
+    
+        self.buttonConnectedIcon = hildon.PickerButton(gtk.HILDON_SIZE_FULLSCREEN_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_HORIZONTAL | hildon.BUTTON_STYLE_NORMAL)
+        self.buttonConnectedIcon.set_title("Indicator:")
+        self.buttonConnectedIcon.set_alignment(0.09, 0.5, 0, 0)
+        self.buttonConnectedIcon.set_selector(self.selectIndicator())
+        try:
+            self.buttonConnectedIcon.set_active(self.list.index(connectedIcon.strip('_')))
+        except:
+            self.buttonConnectedIcon.set_active(0)
+    
         self.buttonStopTracking = hildon.CheckButton(gtk.HILDON_SIZE_FULLSCREEN_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT)
         self.buttonStopTracking.set_label("Stop tracking status when off")
     
+        vboxBorder = gtk.VBox(False, 0)
+        vboxBorder.set_border_width(8)
         vbox = gtk.VBox(False, 0)
-        vbox.set_border_width(8)
-        vbox.pack_start(labelServer, False, False, 10)
+        vbox.set_border_width(0)
+        vbox.pack_start(labelServer, False, False, 12)
         vbox.pack_start(self.buttonAutostart, False, False, 0)
-        vbox.pack_start(labelWidget, False, False, 10)
+        vbox.pack_start(labelWidget, False, False, 12)
         vbox.pack_start(self.buttonConfirm, False, False, 0)
+        vbox.pack_start(self.buttonShowConnected, False, False, 0)
+        vbox.pack_start(self.buttonConnectedIcon, False, False, 0)
         vbox.pack_start(self.buttonStopTracking, False, False, 0)
         
-        window.add(vbox)
+        areaScrolling = hildon.PannableArea()
+        areaScrolling.add_with_viewport(vbox)
+        areaScrolling.set_border_width(0)
+        
+        vboxBorder.pack_start(areaScrolling, True, True, 0)
+        
+        window.add(vboxBorder)
         
         if autostart:
             self.buttonAutostart.set_active(True)
@@ -105,6 +149,12 @@ class Main(object):
             self.buttonConfirm.set_active(True)
         else:
             self.buttonConfirm.set_active(False)
+        if showConnected:
+            self.buttonShowConnected.set_active(True)
+            self.buttonConnectedIcon.set_sensitive(True)
+        else:
+            self.buttonShowConnected.set_active(False)
+            self.buttonConnectedIcon.set_sensitive(False)
         if stopTracking:
             self.buttonStopTracking.set_active(True)
         else:
@@ -112,6 +162,8 @@ class Main(object):
             
         self.buttonAutostart.connect("clicked", self.buttonAutostart_clicked)
         self.buttonConfirm.connect("clicked", self.buttonConfirm_clicked)
+        self.buttonShowConnected.connect("clicked", self.buttonShowConnected_clicked)
+        self.buttonConnectedIcon.connect("value-changed", self.buttonConnectedIcon_changed)
         self.buttonStopTracking.connect("clicked", self.buttonStopTracking_clicked)
         
         menu = self.create_menu()
@@ -135,6 +187,29 @@ class Main(object):
         self.parser.set('options', 'confirmDisconnect', str(confirmDisconnect))
         self.write_config()
 
+    def buttonShowConnected_clicked(self, dummy):
+        global showConnected
+        showConnected = not showConnected
+        if showConnected:
+            self.buttonConnectedIcon.set_sensitive(True)
+        else:
+            self.buttonConnectedIcon.set_sensitive(False)
+        self.parser.set('options', 'showConnected', str(showConnected))
+        self.write_config()
+        
+    def selectIndicator(self):
+        selector = hildon.TouchSelector(text = True)
+        for i in self.list:
+            selector.append_text(i)
+        return selector
+        
+    def buttonConnectedIcon_changed(self, dummy):
+        style = self.buttonConnectedIcon.get_value()
+        while len(style) < 4:
+            style = style + "_"
+        self.parser.set('options', 'connectedIcon', style)
+        self.write_config()
+        
     def buttonStopTracking_clicked(self, dummy):
         global stopTracking
         stopTracking = not stopTracking
@@ -169,13 +244,13 @@ class Main(object):
     
     def about_clicked(self, dummy):
         about = gtk.Dialog("About", None)
+        logo = gtk.image_new_from_file("/usr/share/icons/hicolor/64x64/apps/openssh-status.png")
         textApp = gtk.Label("<big><b>OpenSSH Status Widget  "+version+"</b></big>")
         textApp.set_use_markup(True)
         textApp.set_line_wrap(True)
         textIandI = gtk.Label("Created by Marc Pöpperl (rasmarc)\n")
         vbox2 = gtk.VBox(False,16)
         vbox2.set_border_width(16)
-        logo = gtk.image_new_from_file("/usr/share/icons/hicolor/64x64/apps/openssh-status.png")
         vbox2.pack_start(logo)
         vbox2.pack_start(textApp)
         vbox2.pack_start(textIandI)
